@@ -1,5 +1,5 @@
 def password():
-    x = 0
+    x = "BIcode"
     while x != "BIcode":
         x = input('password : ')
         if x == "BIcode":
